@@ -2,7 +2,7 @@
 # -*- encoding: utf-8 -*-
 
 from pygithub3.core.client import Client
-from pygithub3.core.result import Result
+from pygithub3.core.result import smart, normal
 from pygithub3.requests.base import Factory
 from pygithub3.core.errors import NotFound
 
@@ -41,6 +41,10 @@ class Service(object):
         self._client = Client(**config)
         self.request_builder = Factory()
 
+    @property
+    def remaining_requests(self):
+        return Client.remaining_requests
+
     def get_user(self):
         return self._client.user
 
@@ -83,6 +87,9 @@ class Service(object):
             kwargs['repo'] = kwargs['repo'] or self.get_repo()
         return self.request_builder(request, **kwargs)
 
+    def _request(self, verb, request, **kwargs):
+        self._client.request(verb, request, **kwargs)
+
     def _bool(self, request, **kwargs):
         try:
             self._client.head(request, **kwargs)
@@ -131,7 +138,12 @@ class Service(object):
         return request.resource.loads(response.content)
 
     def _get_result(self, request, **kwargs):
-        return Result(self._client, request, **kwargs)
+        method = smart.Method(self._client.get, request, **kwargs)
+        return smart.Result(method)
+
+    def _get_normal_result(self, request, **kwargs):
+        method = normal.Method(self._client.get, request, **kwargs)
+        return normal.Result(method)
 
 
 class MimeTypeMixin(object):
